PipeMode

Enum PipeMode 

pub enum PipeMode {
    Passthrough,
    Capture,
    Consume,
}

Variants



Passthrough

Pipe to command, but ignore its output and return the original input. Used for side-effects like logging or clipboard where we still want to see the output.



Capture

Pipe to command and use its output as the new result. Used for filters like jq or sort.



Consume

Pipe to command and suppress further output. Used when the pipe destination is the final consumer (e.g. strict clipboard only).